"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path = require("path");
const generate_1 = require("./generate");
async function writeDeclarationFile(pkgDir) {
    const { name, main } = require(path.join(pkgDir, 'package.json'));
    const entry = path.join(pkgDir, main);
    const typings = await generate_1.generateTypings(name, entry);
    const typingsFilename = path.join(pkgDir, 'index.d.ts');
    return fs.writeFile(typingsFilename, typings);
}
async function cli(pkgDir = process.cwd()) {
    try {
        const dirname = path.isAbsolute(pkgDir)
            ? pkgDir
            : path.resolve(process.cwd(), pkgDir);
        await writeDeclarationFile(dirname);
    }
    catch (error) {
        console.error(`Cannot generate declaration file for "${pkgDir}".`);
        console.error(`Reason: ${error.message}`);
        if (error.codeFrame) {
            console.error(error.codeFrame);
        }
        process.exit(1);
    }
}
exports.cli = cli;
//# sourceMappingURL=index.js.map